@@ -7,7 +7,7 @@ import pytest
 from poetry.core.constraints.version import EmptyConstraint
 from poetry.core.constraints.version import Version
 from poetry.core.constraints.version import VersionRange
-from poetry.core.version.exceptions import InvalidVersion
+from poetry.core.version.exceptions import InvalidVersionError
 from poetry.core.version.pep440 import ReleaseTag
 
 
@@ -16,36 +16,52 @@ if TYPE_CHECKING:
 
 
 @pytest.mark.parametrize(
-    "text,version",
+    "text,version,normalized",
     [
-        ("1.0.0", Version.from_parts(1, 0, 0)),
-        ("1", Version.from_parts(1, 0, 0)),
-        ("1.0", Version.from_parts(1, 0, 0)),
-        ("1b1", Version.from_parts(1, 0, 0, pre=ReleaseTag("beta", 1))),
-        ("1.0b1", Version.from_parts(1, 0, 0, pre=ReleaseTag("beta", 1))),
-        ("1.0.0b1", Version.from_parts(1, 0, 0, pre=ReleaseTag("beta", 1))),
-        ("1.0.0-b1", Version.from_parts(1, 0, 0, pre=ReleaseTag("beta", 1))),
-        ("1.0.0-beta.1", Version.from_parts(1, 0, 0, pre=ReleaseTag("beta", 1))),
-        ("1.0.0+1", Version.from_parts(1, 0, 0, local=1)),
-        ("1.0.0-1", Version.from_parts(1, 0, 0, post=ReleaseTag("post", 1))),
-        ("1.0.0.0", Version.from_parts(1, 0, 0, extra=0)),
-        ("1.0.0-post", Version.from_parts(1, 0, 0, post=ReleaseTag("post"))),
-        ("1.0.0-post1", Version.from_parts(1, 0, 0, post=ReleaseTag("post", 1))),
-        ("0.6c", Version.from_parts(0, 6, 0, pre=ReleaseTag("rc", 0))),
-        ("0.6pre", Version.from_parts(0, 6, 0, pre=ReleaseTag("preview", 0))),
-        ("1!2.3.4", Version.from_parts(2, 3, 4, epoch=1)),
+        ("1.0.0", Version.from_parts(1, 0, 0), "1.0.0"),
+        ("1", Version.from_parts(1, 0, 0), "1"),
+        ("1.0", Version.from_parts(1, 0, 0), "1.0"),
+        ("1b1", Version.from_parts(1, 0, 0, pre=ReleaseTag("beta", 1)), "1b1"),
+        ("1.0b1", Version.from_parts(1, 0, 0, pre=ReleaseTag("beta", 1)), "1.0b1"),
+        ("1.0.0b1", Version.from_parts(1, 0, 0, pre=ReleaseTag("beta", 1)), "1.0.0b1"),
+        ("1.0.0-b1", Version.from_parts(1, 0, 0, pre=ReleaseTag("beta", 1)), "1.0.0b1"),
+        (
+            "1.0.0-beta.1",
+            Version.from_parts(1, 0, 0, pre=ReleaseTag("beta", 1)),
+            "1.0.0b1",
+        ),
+        ("1.0.0+1", Version.from_parts(1, 0, 0, local=1), "1.0.0+1"),
+        (
+            "1.0.0-1",
+            Version.from_parts(1, 0, 0, post=ReleaseTag("post", 1)),
+            "1.0.0.post1",
+        ),
+        ("1.0.0.0", Version.from_parts(1, 0, 0, extra=0), "1.0.0.0"),
+        (
+            "1.0.0-post",
+            Version.from_parts(1, 0, 0, post=ReleaseTag("post")),
+            "1.0.0.post0",
+        ),
+        (
+            "1.0.0-post1",
+            Version.from_parts(1, 0, 0, post=ReleaseTag("post", 1)),
+            "1.0.0.post1",
+        ),
+        ("0.6c", Version.from_parts(0, 6, 0, pre=ReleaseTag("rc", 0)), "0.6rc0"),
+        ("0.6pre", Version.from_parts(0, 6, 0, pre=ReleaseTag("preview", 0)), "0.6rc0"),
+        ("1!2.3.4", Version.from_parts(2, 3, 4, epoch=1), "1!2.3.4"),
     ],
 )
-def test_parse_valid(text: str, version: Version) -> None:
+def test_parse_valid(text: str, version: Version, normalized: str) -> None:
     parsed = Version.parse(text)
 
     assert parsed == version
-    assert parsed.text == text
+    assert parsed.text == normalized
 
 
 @pytest.mark.parametrize("value", [None, "example"])
 def test_parse_invalid(value: str | None) -> None:
-    with pytest.raises(InvalidVersion):
+    with pytest.raises(InvalidVersionError):
         Version.parse(value)  # type: ignore[arg-type]
 
 
@@ -570,3 +586,21 @@ def test_difference() -> None:
 )
 def test_to_string_normalizes(version: str, normalized_version: str) -> None:
     assert Version.parse(version).to_string() == normalized_version
+
+
+@pytest.mark.parametrize(
+    "unsorted, sorted_",
+    [
+        (["1.0.3", "1.0.2", "1.0.1"], ["1.0.1", "1.0.2", "1.0.3"]),
+        (["1.0.0.2", "1.0.0.0rc2"], ["1.0.0.0rc2", "1.0.0.2"]),
+        (["1.0.0.0", "1.0.0.0rc2"], ["1.0.0.0rc2", "1.0.0.0"]),
+        (["1.0.0.0.0", "1.0.0.0rc2"], ["1.0.0.0rc2", "1.0.0.0.0"]),
+        (["1.0.0rc2", "1.0.0rc1"], ["1.0.0rc1", "1.0.0rc2"]),
+        (["1.0.0rc2", "1.0.0b1"], ["1.0.0b1", "1.0.0rc2"]),
+    ],
+)
+def test_versions_are_sortable(unsorted: list[str], sorted_: list[str]) -> None:
+    unsorted_parsed = [Version.parse(u) for u in unsorted]
+    sorted_parsed = [Version.parse(s) for s in sorted_]
+
+    assert sorted(unsorted_parsed) == sorted_parsed
